Module: AuthlogicCrowd::ActsAsAuthentic
- Defined in:
- lib/authlogic_crowd/acts_as_authentic.rb
Defined Under Namespace
Modules: ClassMethods, Config, Methods
Class Method Summary collapse
-
.included(klass) ⇒ Object
Adds in the neccesary modules for acts_as_authentic to include and also disabled password validation if Crowd is being used.
Class Method Details
.included(klass) ⇒ Object
Adds in the neccesary modules for acts_as_authentic to include and also disabled password validation if Crowd is being used.
5 6 7 8 9 10 11 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 5 def self.included(klass) klass.class_eval do extend Config add_acts_as_authentic_module(ActsAsAuthenticCallbacks) add_acts_as_authentic_module(Methods) end end |