Module: AuthlogicCrowd::ActsAsAuthentic::Config
- Defined in:
- lib/authlogic_crowd/acts_as_authentic.rb
Instance Method Summary collapse
-
#add_crowd_records(value = nil) ⇒ Object
(also: #add_crowd_records=)
Should new local records be added to crowd? Default is false.
-
#crowd_app_name(name = nil) ⇒ Object
(also: #crowd_app_name=)
REQUIRED.
-
#crowd_app_password(password = nil) ⇒ Object
(also: #crowd_app_password=)
REQUIRED.
- #crowd_enabled(value = nil) ⇒ Object (also: #crowd_enabled=)
-
#crowd_service_url(url = nil) ⇒ Object
(also: #crowd_service_url=)
REQUIRED.
-
#update_crowd_records(value = nil) ⇒ Object
(also: #update_crowd_records=)
Should changes to local records be synced to crowd? Default is true.
Instance Method Details
#add_crowd_records(value = nil) ⇒ Object Also known as: add_crowd_records=
Should new local records be added to crowd? Default is false.
43 44 45 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 43 def add_crowd_records(value=nil) rw_config(:add_crowd_records, value, false) end |
#crowd_app_name(name = nil) ⇒ Object Also known as: crowd_app_name=
REQUIRED
Specify your crowd app name.
27 28 29 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 27 def crowd_app_name(name=nil) rw_config(:crowd_app_name, name, nil) end |
#crowd_app_password(password = nil) ⇒ Object Also known as: crowd_app_password=
REQUIRED
Specify your crowd app password.
36 37 38 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 36 def crowd_app_password(password=nil) rw_config(:crowd_app_password, password, nil) end |
#crowd_enabled(value = nil) ⇒ Object Also known as: crowd_enabled=
55 56 57 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 55 def crowd_enabled(value=nil) rw_config(:crowd_enabled, value, true) end |
#crowd_service_url(url = nil) ⇒ Object Also known as: crowd_service_url=
REQUIRED
Specify your crowd service url.
18 19 20 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 18 def crowd_service_url(url=nil) rw_config(:crowd_service_url, url, "http://localhost:8095/crowd/services/SecurityServer") end |
#update_crowd_records(value = nil) ⇒ Object Also known as: update_crowd_records=
Should changes to local records be synced to crowd? Default is true
50 51 52 |
# File 'lib/authlogic_crowd/acts_as_authentic.rb', line 50 def update_crowd_records(value=nil) rw_config(:update_crowd_records, value, true) end |