Module: AuthlogicCrowd::Session::Config
- Defined in:
- lib/authlogic_crowd/session.rb
Overview
Configuration for the crowd feature.
Instance Method Summary collapse
-
#auto_register(value = true) ⇒ Object
(also: #auto_register=)
Add this in your Session object if you need to disable auto-registration via crowd.
- #auto_register_value(value = nil) ⇒ Object
-
#crowd_auth_every(value = nil) ⇒ Object
(also: #crowd_auth_every=)
How often should Crowd re-authorize (in seconds).
Instance Method Details
#auto_register(value = true) ⇒ Object Also known as: auto_register=
Add this in your Session object if you need to disable auto-registration via crowd
35 36 37 |
# File 'lib/authlogic_crowd/session.rb', line 35 def auto_register(value=true) auto_register_value(value) end |
#auto_register_value(value = nil) ⇒ Object
39 40 41 |
# File 'lib/authlogic_crowd/session.rb', line 39 def auto_register_value(value=nil) rw_config(:auto_register,value,true) end |
#crowd_auth_every(value = nil) ⇒ Object Also known as: crowd_auth_every=
How often should Crowd re-authorize (in seconds). Default is 0 (always re-authorize)
26 27 28 |
# File 'lib/authlogic_crowd/session.rb', line 26 def crowd_auth_every(value = nil) rw_config(:crowd_auth_every, value, 0) end |